# OpenBB Stockgrid Provider

This extension integrates the [Stockgrid](https://Stockgrid.io/) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-stockgrid
```

Documentation available [here](https://docs.openbb.co/platform/development/contributing).
